@@ -1,7 +1,8 @@
 #' Calculates the GLCM Texture Metrics from a GLCM
 #'
-#' @param GLCM A numeric matrix representing a Normalized GLCM.
+#' @param GLCM A numeric matrix or list of matrices representing a Normalized GLCM.
 #' @param metrics A vector of texture metrics to return. Valid entries include "glcm_contrast", "glcm_dissimilarity", "glcm_homogeneity", "glcm_ASM", "glcm_entropy", "glcm_mean", "glcm_variance", "glcm_correlation".
+#' @param average Logical indicating whether to average metrics across the supplied GLCMs
 #' @return GLCM based texture measures as a numeric vector.
 #' @examples
 #' test_matrix<- matrix(data=c(2,0,1,3,0,0,0,3,2), nrow = 3, ncol=3)
@@ -15,10 +16,10 @@
 #'
 #' Haralick, R.M., Shanmugam, K., Dinstein, I., 1973. Textural features for image classification. IEEE Transactions on Systems, Man, and Cybernetics 610–621. https://doi.org/10.1109/TSMC.1973.4309314
 #' @export
-glcm_metrics<-function(GLCM, metrics= c("glcm_contrast", "glcm_dissimilarity", "glcm_homogeneity", "glcm_ASM", "glcm_entropy", "glcm_mean", "glcm_variance", "glcm_correlation", "glcm_SA")){
-  all_metrics<- c("glcm_contrast", "glcm_dissimilarity", "glcm_homogeneity", "glcm_ASM", "glcm_entropy", "glcm_mean", "glcm_variance", "glcm_correlation", "glcm_SA")
+glcm_metrics<-function(GLCM, metrics= c("glcm_contrast", "glcm_dissimilarity", "glcm_homogeneity", "glcm_ASM", "glcm_entropy", "glcm_mean", "glcm_variance", "glcm_correlation"), average=FALSE){
+  all_metrics<- c("glcm_contrast", "glcm_dissimilarity", "glcm_homogeneity", "glcm_ASM", "glcm_entropy", "glcm_mean", "glcm_variance", "glcm_correlation")
   if (any(!(metrics %in% all_metrics))){
-    stop("Error: Invlaid metric. Valid metrics include 'glcm_contrast', 'glcm_dissimilarity', 'glcm_homogeneity', 'glcm_ASM', 'glcm_entropy', 'glcm_mean', 'glcm_variance', 'glcm_correlation', 'glcm_SA'")
+    stop("Error: Invlaid metric. Valid metrics include 'glcm_contrast', 'glcm_dissimilarity', 'glcm_homogeneity', 'glcm_ASM', 'glcm_entropy', 'glcm_mean', 'glcm_variance', 'glcm_correlation'")
   }
   needed_metrics<- metrics
   if(("glcm_variance" %in% needed_metrics) & (!("glcm_mean" %in% needed_metrics))){
@@ -31,11 +32,21 @@ glcm_metrics<-function(GLCM, metrics= c("glcm_contrast", "glcm_dissimilarity", "
     needed_metrics<- c(needed_metrics, "glcm_variance")
   } #Some metrics needed
 
-  i_mat<- matrix(data= 0:(nrow(GLCM)-1), nrow= nrow(GLCM), ncol=ncol(GLCM), byrow=FALSE)
-  j_mat<- matrix(data= 0:(ncol(GLCM)-1), nrow= nrow(GLCM), ncol=ncol(GLCM), byrow=TRUE)
-  n_levels=nrow(GLCM)
-  k_vals<- seq((2*n_levels)-1)-1
-  out<- C_glcm_metrics(Pij = GLCM, i_mat = i_mat, j_mat = j_mat, n_levels=n_levels, k_vals=k_vals, metrics = needed_metrics)
-  out<- out[names(out) %in% metrics] #Subset to requsted metrics
-  return(out)
+  if(!is.list(GLCM)){GLCM<- list(GLCM)}
+  out<- vector(mode="list", length = length(GLCM))
+
+  for (i in 1:length(GLCM)) {
+    i_mat<- matrix(data= 0:(nrow(GLCM[[i]])-1), nrow= nrow(GLCM[[i]]), ncol=ncol(GLCM[[i]]), byrow=FALSE)
+    j_mat<- matrix(data= 0:(ncol(GLCM[[i]])-1), nrow= nrow(GLCM[[i]]), ncol=ncol(GLCM[[i]]), byrow=TRUE)
+    n_levels=nrow(GLCM[[i]])
+    k_vals<- seq((2*n_levels)-1)-1
+    out[[i]]<- C_glcm_metrics(GLCM[[i]], i_mat = i_mat, j_mat = j_mat, n_levels=n_levels, k_vals=k_vals, metrics = needed_metrics)
+    out[[i]]<-  out[[i]][names(out[[i]]) %in% metrics]
   }
+  if(length(out)==1){out<- out[[1]]}
+  if(average){
+    out<- colMeans(do.call(rbind, out)) # average across shifts
+  }
+  return(out)
+}
+
