@@ -1,6 +1,6 @@
 #' Creates a symmetrical normalized GLCM for a given matrix and shift
 #'
-#' @param x a matrix of integers representing quantized values. The valid range of values is from 0 to n_levels-1 (e.g. a matrix with 32 grey levels would have a valid range of 0-31).
+#' @param x a matrix, SpatRaster, or RasterLayer containing integers representing quantized values. The valid range of values is from 0 to n_levels-1 (e.g. a matrix with 32 grey levels would have a valid range of 0-31).
 #' @param n_levels Number of grey levels used in the quantization
 #' @param shift A vector of length 2 specifying the relationship between neighboring pixel to the reference pixel. The first number represents the shift in the x direction and the second number represents the shift in the y direction, where up and right are positive. For example c(1,0) is the pixel directly to the right. The GLCM is made symmetrical by counting each pair twice, once "forwards" and once "backwards" by interchanging reference and neighbor pixels. Therefore a shift directly to the right c(1,0) is equivalent to a shift directly to the left c(-1,0)
 #' @param na.rm a logical value indicating whether NA values should be stripped before the computation proceeds (default=FALSE)
@@ -19,12 +19,24 @@
 #' @export
 
 make_glcm<- function(x, n_levels, shift, na.rm = FALSE, normalize=TRUE){
-	if(isTRUE(any(x > (n_levels-1))) | isTRUE(any(x < 0))){
+  if(class(x)[1]!="matrix"){
+    x<- as.matrix(x, wide=TRUE)
+  } # Convert to matrix
+  if(isTRUE(any(x > (n_levels-1))) | isTRUE(any(x < 0))){
 	  stop("Error: x must have values between 0 and n_levels-1")
-	  }
-  if(normalize){
-	  return(C_make_glcm(x=x, n_levels=n_levels, shift=shift, na_rm=na.rm))
-	  } else{
-	    return(C_make_glcm_counts(x=x, n_levels=n_levels, shift=shift, na_rm=na.rm))
-	  }
+	}
+  if(!is.list(shift)){shift<- list(shift)}
+  GLCM<- vector(mode="list", length = length(shift))
+
+  for (i in 1:length(shift)) {
+    if(normalize){
+      GLCM[[i]]<- C_make_glcm(x=x, n_levels=n_levels, shift=shift[[i]], na_rm=na.rm)
+    } else{
+      GLCM[[i]]<- C_make_glcm_counts(x=x, n_levels=n_levels, shift=shift[[i]], na_rm=na.rm)
+    }
   }
+  if(length(GLCM)==1){GLCM<- GLCM[[1]]}
+  return(GLCM)
+}
+
+
